(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14309,        470]
NotebookOptionsPosition[     11987,        393]
NotebookOutlinePosition[     12622,        418]
CellTagsIndexPosition[     12537,        413]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Integration by Parts", "Title",
 CellChangeTimes->{{3.464516976348936*^9, 3.464516983346324*^9}}],

Cell[CellGroupData[{

Cell["Where the formula comes from.", "Section",
 CellChangeTimes->{{3.4645170543401737`*^9, 3.464517062788052*^9}}],

Cell["\<\
One of the basic rules for differentiating, the product rule,  gives us a \
useful formula for finding integrals.\
\>", "Text",
 CellChangeTimes->{{3.464517126540674*^9, 3.464517188182478*^9}}],

Cell["Differentiating a product of two functions.", "MathCaption",
 CellChangeTimes->{{3.464517803068987*^9, 3.4645178322328043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], " ", 
    RowBox[{"g", "[", "x", "]"}]}], ",", "x"}], "]"}]], "Input",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.464517200663608*^9, 3.464517257386381*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "x", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "x", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], " ", 
   RowBox[{
    SuperscriptBox["g", "\[Prime]",
     MultilineFunction->None], "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.464517211626981*^9, 3.4645172592715883`*^9}}]
}, Open  ]],

Cell["\<\
Thus, since integration amounts to finding an antiderivative, we can write:\
\>", "MathCaption",
 CellChangeTimes->{{3.46451734420228*^9, 3.464517377288308*^9}, {
  3.464517854844553*^9, 3.4645178650765333`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", " ", 
    RowBox[{"(", "x", ")"}], " ", 
    RowBox[{"g", "(", "x", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"g", "(", "x", ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox["g", "\[Prime]",
       MultilineFunction->None], "(", "x", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.464517399521645*^9, 3.464517497621667*^9}, {
  3.464517531305825*^9, 3.464517542214734*^9}}],

Cell["But, the integral of a sum is the sum of the integrals.", "MathCaption",
 CellChangeTimes->{{3.4645175802239227`*^9, 3.464517597293076*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", " ", 
    RowBox[{"(", "x", ")"}], " ", 
    RowBox[{"g", "(", "x", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"g", "(", "x", ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], "+", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"f", "(", "x", ")"}], " ", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.464517625540955*^9, 3.464517632680345*^9}}],

Cell["Solving for the first integral on the right gives us:", "MathCaption",
 CellChangeTimes->{{3.4645179210790577`*^9, 3.4645179375635767`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{"g", "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "=", 
   RowBox[{
    RowBox[{"f", " ", 
     RowBox[{"(", "x", ")"}], " ", 
     RowBox[{"g", "(", "x", ")"}]}], " ", "-", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"f", "(", "x", ")"}], " ", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.464517963170896*^9, 3.464517978905055*^9}}],

Cell[TextData[{
 "Finally,we set ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], "=", "u"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", "v"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["g", "\[Prime]",
      MultilineFunction->None], "(", "x", ")"}], "=", 
    RowBox[{"\[DifferentialD]", "u"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "(", "x", ")"}], "=", 
    RowBox[{"\[DifferentialD]", "v"}]}], TraditionalForm]]],
 " to get:"
}], "MathCaption",
 CellChangeTimes->{{3.464518001377038*^9, 3.46451811168919*^9}, {
  3.464518178088908*^9, 3.464518383491424*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{"u", " ", 
     RowBox[{"\[DifferentialD]", "v"}]}]}], "=", 
   RowBox[{
    RowBox[{"u", " ", "v"}], "-", 
    RowBox[{"\[Integral]", 
     RowBox[{"v", " ", 
      RowBox[{"\[DifferentialD]", "u"}]}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.464518138221438*^9, 3.464518167697649*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the Formula", "Section",
 CellChangeTimes->{{3.4645184048770647`*^9, 3.464518413548581*^9}}],

Cell[TextData[{
 "To use the formula we need to identify the values for ",
 StyleBox["u",
  FontSlant->"Italic"],
 " and ",
 StyleBox["v",
  FontSlant->"Italic"],
 ". This is most easily understood by example. Consider the integral ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{"x", " ", 
      RowBox[{"cos", "(", "x", ")"}]}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.4645186121788073`*^9, 3.464518715730936*^9}, {
  3.464518748383316*^9, 3.464518750699885*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{GridBox[{
     {"\"\<substitution\>\"", "\"\<function\>\"", "\"\<derivative\>\""},
     {"u", "\"\<x\>\"", "\"\<1 \[DifferentialD]x\>\""},
     {"v", "\"\<Sin[x]\>\"", "\"\<Cos[x]\[DifferentialD]x\>\""}
    },
    GridBoxDividers->{
     "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
      "RowsIndexed" -> {}}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.464518838138317*^9, 3.464519077073535*^9}, {
  3.464522589357194*^9, 3.464522610835956*^9}, {3.464522653090501*^9, 
  3.4645227337855177`*^9}, {3.464522764950039*^9, 3.464522768673908*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"substitution\"\>", "\<\"function\"\>", "\<\"derivative\"\>"},
    {"u", "\<\"x\"\>", "\<\"1 \[DifferentialD]x\"\>"},
    {"v", "\<\"Sin[x]\"\>", "\<\"Cos[x]\[DifferentialD]x\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.4645237107756777`*^9},
 TextAlignment->Center,
 TextJustification->0.]
}, {2}]],

Cell["Taking values from the table we have the following:", "MathCaption",
 CellChangeTimes->{{3.46452347952079*^9, 3.464523491270372*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"sin", "(", "x", ")"}]}], "-", 
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{"sin", "(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.4645235045605927`*^9, 3.4645235519385557`*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell["\<\
Since we know how to integrate sin(x) we can easily finish solving the \
problem.\
\>", "Text",
 CellChangeTimes->{{3.464523606352861*^9, 3.464523638002225*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The PartsIntegrate Function", "Section",
 CellChangeTimes->{{3.4645236478674383`*^9, 3.464523659657673*^9}}],

Cell["\<\
In today's class we will use the PartsIntegrate function. To use this \
function you will need to load a package.\
\>", "Text",
 CellChangeTimes->{{3.46452376513592*^9, 3.464523811388474*^9}}],

Cell["Loading the package", "MathCaption",
 CellChangeTimes->{{3.464523828825886*^9, 3.4645238334849043`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "IntegrationTechniques`"}]], "Input",
 CellChangeTimes->{{3.464523835871677*^9, 3.464523846896035*^9}}],

Cell["Finding out about the function.", "MathCaption",
 CellChangeTimes->{{3.464523863971561*^9, 3.464523869853812*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PartsIntegrate"}]], "Input",
 CellChangeTimes->{{3.4645238764377327`*^9, 3.4645238827706413`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"PartsIntegrate[integrand,variable,{u,dv}] returns the result \
of integrating the integrand with respect to the variable using the method \
integral[u dv]= u v - integral[v du]\"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]}]], "Print",\
 "PrintUsage",
 CellChangeTimes->{3.464523884673626*^9},
 CellTags->"Info3464505884-3505604"]
}, Open  ]],

Cell[TextData[{
 "We see that we need the same information to use the function that we needed \
to solve the example above, the integrand, the variable and what to use for \
",
 StyleBox["u",
  FontSlant->"Italic"],
 " and \[DifferentialD]v."
}], "Text",
 CellChangeTimes->{{3.464523902098837*^9, 3.464523957239821*^9}}],

Cell["Trying the function with our example.", "MathCaption",
 CellChangeTimes->{{3.464523982555705*^9, 3.4645239907209883`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartsIntegrate", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Cos", "[", "x", "]"}]}], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"Cos", "[", "x", "]"}]}], "}"}]}], "]"}]], "Input",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.4645239705945463`*^9, 3.464524032836308*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"Int", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", "x"}], "]"}]}], "+", 
  RowBox[{"x", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{3.464524037210598*^9}]
}, Open  ]],

Cell["\<\
The part of the solution that begins with \"Int\" is just the integral in the \
integrate by parts formula. We can remove the Int and evaluate the integral \
using the RemoveInt function.\
\>", "Text",
 CellChangeTimes->{{3.464524055533*^9, 3.464524132547202*^9}}],

Cell["\<\
Removing \"Int\" and finishing the problem to get the result we had above.\
\>", "MathCaption",
 CellChangeTimes->{{3.4645241869909353`*^9, 3.464524225677513*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RemoveInt", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Int", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], ",", "x"}], "]"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}]], "Input",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.464524136472826*^9, 3.46452414190475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", "x", "]"}], "+", 
  RowBox[{"x", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4645241433201427`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
WindowSize->{931, 782},
WindowMargins->{{Automatic, 119}, {Automatic, 0}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3464505884-3505604"->{
  Cell[9337, 305, 519, 12, 69, "Print",
   CellTags->"Info3464505884-3505604"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3464505884-3505604", 12433, 407}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 103, 1, 95, "Title"],
Cell[CellGroupData[{
Cell[695, 27, 116, 1, 83, "Section"],
Cell[814, 30, 203, 4, 32, "Text"],
Cell[1020, 36, 134, 1, 50, "MathCaption"],
Cell[CellGroupData[{
Cell[1179, 41, 252, 7, 33, "Input"],
Cell[1434, 50, 406, 12, 35, "Output"]
}, Open  ]],
Cell[1855, 65, 222, 4, 50, "MathCaption"],
Cell[2080, 71, 717, 21, 46, "DisplayFormula"],
Cell[2800, 94, 146, 1, 50, "MathCaption"],
Cell[2949, 97, 746, 22, 46, "DisplayFormula"],
Cell[3698, 121, 146, 1, 50, "MathCaption"],
Cell[3847, 124, 737, 22, 46, "DisplayFormula"],
Cell[4587, 148, 820, 30, 52, "MathCaption"],
Cell[5410, 180, 388, 12, 46, "DisplayFormula"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5835, 197, 104, 1, 83, "Section"],
Cell[5942, 200, 563, 18, 58, "Text"],
Cell[CellGroupData[{
Cell[6530, 222, 711, 15, 231, "Input"],
Cell[7244, 239, 501, 12, 85, "Output"]
}, {2}]],
Cell[7757, 254, 139, 1, 50, "MathCaption"],
Cell[7899, 257, 382, 12, 46, "DisplayFormula"],
Cell[8284, 271, 171, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8492, 280, 114, 1, 83, "Section"],
Cell[8609, 283, 202, 4, 32, "Text"],
Cell[8814, 289, 110, 1, 50, "MathCaption"],
Cell[8927, 292, 132, 2, 33, "Input"],
Cell[9062, 296, 120, 1, 50, "MathCaption"],
Cell[CellGroupData[{
Cell[9207, 301, 127, 2, 33, "Input"],
Cell[9337, 305, 519, 12, 69, "Print",
 CellTags->"Info3464505884-3505604"]
}, Open  ]],
Cell[9871, 320, 320, 8, 51, "Text"],
Cell[10194, 330, 128, 1, 50, "MathCaption"],
Cell[CellGroupData[{
Cell[10347, 335, 331, 9, 33, "Input"],
Cell[10681, 346, 253, 8, 33, "Output"]
}, Open  ]],
Cell[10949, 357, 274, 5, 51, "Text"],
Cell[11226, 364, 173, 3, 50, "MathCaption"],
Cell[CellGroupData[{
Cell[11424, 371, 342, 10, 33, "Input"],
Cell[11769, 383, 178, 5, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
