(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     27667,       1008]
NotebookOptionsPosition[     21942,        818]
NotebookOutlinePosition[     23553,        858]
CellTagsIndexPosition[     23510,        855]
WindowTitle->Using Integration Techniques Functions - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["IntegrationTechniques",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:IntegrationTechniques/guide/IntegrationTechniques"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["INTEGRATION TECHNIQUES TUTORIAL", "PacletNameCell"], Cell[
    TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Functions \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PartsIntegrate\"\>":>
       Documentation`HelpLookup[
       "paclet:IntegrationTechniques/ref/PartsIntegrate"], \
"\<\"RemoveInt\"\>":>Documentation`HelpLookup[
       "paclet:IntegrationTechniques/ref/RemoveInt"], "\<\"SIntegrate\"\>":>
       Documentation`HelpLookup[
       "paclet:IntegrationTechniques/ref/SIntegrate"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"IntegrationTechniques/tutorial/\
UsingIntegrationTechniquesFunctions\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
             "IntegrationTechniques/tutorial/\
UsingIntegrationTechniquesFunctions"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/\
IntegrationTechniques/tutorial/UsingIntegrationTechniquesFunctions.html"], 
                StandardForm]], "Input", TextClipboardType -> "PlainText"]}, 
            Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "IntegrationTechniques/tutorial/\
UsingIntegrationTechniquesFunctions", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell[CellGroupData[{

Cell["Using Integration Techniques Functions", "Title",
 CellID->509267359],

Cell[TextData[{
 "The functions defined in ",
 Cell[BoxData[
  ButtonBox["IntegrationTechniques`",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/IntegrationTechniques`"]], 
  "InlineFormula"],
 "  provide tools for having students become familiar with the concepts of \
modifying an integrand to produce an equivalent but recognizable integrand."
}], "Text",
 CellID->1534169418],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["PartsIntegrate",
      BaseStyle->"Link",
      ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"], "[", 
     RowBox[{
      StyleBox["intgrnd", "TI"], ",", 
      StyleBox["var", "TI"], ",", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["u", "TI"], ",", 
        RowBox[{"\[DifferentialD]", 
         StyleBox["v", "TI"]}]}], "}"}]}], "]"}], Cell[
    "use the method of integration by parts", "TableText"]},
   {
    RowBox[{
     ButtonBox["SIntegrate",
      BaseStyle->"Link",
      ButtonData->"paclet:IntegrationTechniques/ref/SIntegrate"], "[", 
     RowBox[{
      StyleBox["intgrnd", "TI"], ",", 
      StyleBox["var", "TI"], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         StyleBox["expr", "TI"], "\[Rule]", 
         StyleBox["u", "TI"]}], ",", 
        RowBox[{
         RowBox[{"\[DifferentialD]", 
          StyleBox["var", "TI"]}], "\[Rule]", " ", 
         RowBox[{
          StyleBox["coef", "TI"], " ", 
          RowBox[{"\[DifferentialD]", 
           StyleBox["u", "TI"]}]}]}]}], "}"}]}], "]"}], Cell[
    "simplify an integral using substitution", "TableText"]},
   {
    RowBox[{
     ButtonBox["RemoveInt",
      BaseStyle->"Link",
      ButtonData->"paclet:IntegrationTechniques/ref/RemoveInt"], "[", 
     StyleBox["expr", "TI"], "]"}], Cell[
    "integrate the results of using PartIntegrate or SIntegrate", "TableText"]}
  }]], "DefinitionBox",
 CellID->2096742444],

Cell["Functions for simplifying integrals.", "Caption",
 CellID->1891092685],

Cell["This loads the package:", "MathCaption",
 CellID->836781195],

Cell[BoxData[
 RowBox[{"<<", "IntegrationTechniques`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->2058623809],

Cell[CellGroupData[{

Cell["Integrating Using Substitution", "Section",
 CellID->501870413],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["SIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/SIntegrate"]], 
  "InlineFormula"],
 " function is intended for use where the method of substitution would be \
appropriate. The student is presented with the integral to evaluate and then \
asked to find appropriate substitutions to simplify the integral. The teacher \
would then enter the substitutions into the ",
 Cell[BoxData[
  ButtonBox["SIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/SIntegrate"]], 
  "InlineFormula"],
 " function and evaluate to obtain an unevaluated integral simpler in form \
than the original. The students could then be asked for the result of \
performing the simpler integration. The result can be checked using RemoveInt."
}], "Text",
 CellID->1767749522],

Cell[TextData[{
 "Evaluate the integral ",
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox[
     RowBox[{"Cos", "[", 
      SqrtBox["x"], "]"}], 
     SqrtBox["x"]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 "."
}], "Text",
 CellID->129960009],

Cell["Putting this into the SIntegrate function.", "MathCaption",
 CellID->281161397],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SIntegrate", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", 
     SqrtBox["x"], "]"}], 
    SqrtBox["x"]], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["x"], "\[Rule]", " ", "u"}], ",", 
     RowBox[{
      RowBox[{"\[DifferentialD]", "x"}], "\[Rule]", " ", 
      RowBox[{"2", " ", 
       SqrtBox["x"], 
       RowBox[{"\[DifferentialD]", "u"}]}]}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->1015575979],

Cell[BoxData[
 RowBox[{"Int", "[", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "u", "]"}]}], ",", "u"}], "]"}]], "Output",
 ImageSize->{111, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[25]=",
 CellID->585452697]
}, Open  ]],

Cell["\<\
The students should now recognize the integral as one they can solve.\
\>", "Text",
 CellID->2080891572],

Cell["Checking the result using RemoveInt.", "MathCaption",
 CellID->1773459209],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RemoveInt", "[", 
  RowBox[{"Int", "[", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "u", "]"}]}], ",", "u"}], "]"}], "]"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->1603388950],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Sin", "[", "u", "]"}]}]], "Output",
 ImageSize->{57, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->1533280094]
}, Open  ]],

Cell["\<\
Finally the original substitution is reversed using rules to get the final \
answer.\
\>", "MathCaption",
 CellID->34775858],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", "u", "]"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{"u", "\[Rule]", " ", 
    SqrtBox["x"]}], "}"}]}]], "Input",
 CellLabel->"In[27]:=",
 CellID->1845657267],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Sin", "[", 
   SqrtBox["x"], "]"}]}]], "Output",
 ImageSize->{72, 20},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]=",
 CellID->1707889201]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrating Using Method of Parts", "Section",
 CellID->1227375405],

Cell[TextData[{
 "Using ",
 Cell[BoxData[
  ButtonBox["PartsIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]], 
  "InlineFormula"],
 " is done in a manner similar to what was done in ",
 Cell[BoxData[
  ButtonBox["SIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/SIntegrate"]], 
  "InlineFormula"],
 ". The students are presented with an integral where integration by parts is \
appropriate and asked to identify the parts to use in carrying out the \
integration. As before the result is given as an expression with head Int."
}], "Text",
 CellID->1918002400],

Cell[TextData[{
 "Evaluate the integral ",
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", "x", "]"}], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 "."
}], "Text",
 CellID->2136795330],

Cell[TextData[{
 "Using the ",
 Cell[BoxData[
  ButtonBox["PartsIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]], 
  "InlineFormula"],
 " function to simplify the integral."
}], "MathCaption",
 CellID->750082529],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartsIntegrate", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"Sin", "[", "x", "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->908057013],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "x"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{"Int", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", "x", "]"}]}], ",", "x"}], "]"}]}]], "Output",
 ImageSize->{183, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->1695421909]
}, Open  ]],

Cell[TextData[{
 "Using ",
 Cell[BoxData[
  ButtonBox["RemoveInt",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/RemoveInt"]], 
  "InlineFormula"],
 " to produce the final result."
}], "MathCaption",
 CellID->2142996167],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RemoveInt", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    RowBox[{"Cos", "[", "x", "]"}]}], "-", 
   RowBox[{"Int", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "x", "]"}]}], ",", "x"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->1888334932],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "x"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"Sin", "[", "x", "]"}]}]], "Output",
 ImageSize->{121, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->1731866758]
}, Open  ]],

Cell["\<\
In some instances integration by parts is used more than once. Parts \
integrate will work on the parts of the expression having the head Int.\
\>", "Text",
 CellID->491250268],

Cell[TextData[{
 "Here we take ",
 StyleBox["u = ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 "and ",
 StyleBox["dv = sin(x)",
  FontSlant->"Italic"],
 " which returns an expression which requires a second use of integration by \
parts."
}], "MathCaption",
 CellID->1516115208],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartsIntegrate", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["x", "2"], ",", 
     RowBox[{"Sin", "[", "x", "]"}]}], "}"}]}], "]"}]], "Input",
 CellID->1454829201],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["x", "2"]}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{"Int", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "x", " ", 
     RowBox[{"Cos", "[", "x", "]"}]}], ",", "x"}], "]"}]}]], "Output",
 ImageSize->{209, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->65576465]
}, Open  ]],

Cell[TextData[{
 "We can copy the above result down using \[CommandKey]\[KeyBar]\[ShiftKey]\
\[LeftModified]l\[RightModified] and apply ",
 Cell[BoxData[
  ButtonBox["PartsIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]], 
  "InlineFormula"],
 " to the expression containing \[OpenCurlyDoubleQuote]Int\
\[CloseCurlyDoubleQuote]."
}], "MathCaption",
 CellID->484536344],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["x", "2"]}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{"PartsIntegrate", "[", 
   RowBox[{
    RowBox[{"Int", "[", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "x", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}], "]"}], ",", "x", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "x"}], ",", 
      RowBox[{"Cos", "[", "x", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellID->344344184],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["x", "2"]}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"Int", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"Sin", "[", "x", "]"}]}], ",", "x"}], "]"}], "+", 
  RowBox[{"2", " ", "x", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Output",
 ImageSize->{275, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->2071755470]
}, Open  ]],

Cell[TextData[{
 "We finish using ",
 Cell[BoxData[
  ButtonBox["RemoveInt",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/RemoveInt"]], 
  "InlineFormula"],
 "."
}], "MathCaption",
 CellID->694331832],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RemoveInt", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["x", "2"]}], " ", 
    RowBox[{"Cos", "[", "x", "]"}]}], "+", 
   RowBox[{"Int", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"Sin", "[", "x", "]"}]}], ",", "x"}], "]"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellID->208962626],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["x", "2"], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"2", " ", "x", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Output",
 ImageSize->{205, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->899092337]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Substitution Followed by Integration by Parts", "Section",
 CellID->1349967667],

Cell[TextData[{
 "In many instances several methods need to be used to simplify an integral \
to a recognizable form. ",
 Cell[BoxData[
  ButtonBox["SIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/SIntegrate"]], 
  "InlineFormula"],
 " can be combined with ",
 Cell[BoxData[
  ButtonBox["PartsIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]], 
  "InlineFormula"],
 " to solve such integrals."
}], "Text",
 CellID->741848714],

Cell[TextData[{
 "Evaluate the integral ",
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{
    RowBox[{"Sin", "[", 
     SqrtBox["x"], "]"}], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 "."
}], "Text",
 CellID->2108765363],

Cell["We begin using substitution.", "MathCaption",
 CellID->2096829500],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SIntegrate", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    SqrtBox["x"], "]"}], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", " ", 
      SuperscriptBox["r", "2"]}], ",", 
     RowBox[{
      RowBox[{"\[DifferentialD]", "x"}], "\[Rule]", " ", 
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"\[DifferentialD]", "r"}]}]}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->1206759230],

Cell[BoxData[
 RowBox[{"Int", "[", 
  RowBox[{
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"Sin", "[", 
     SqrtBox[
      SuperscriptBox["r", "2"]], "]"}]}], ",", "r"}], "]"}]], "Output",
 ImageSize->{143, 28},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->1166816342]
}, Open  ]],

Cell["Next we simplify assuming r>0.", "MathCaption",
 CellID->2009079237],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Int", "[", 
    RowBox[{
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"Sin", "[", 
       SqrtBox[
        SuperscriptBox["r", "2"]], "]"}]}], ",", "r"}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->1709354478],

Cell[BoxData[
 RowBox[{"Int", "[", 
  RowBox[{
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"Sin", "[", "r", "]"}]}], ",", "r"}], "]"}]], "Output",
 ImageSize->{121, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[31]=",
 CellID->84482180]
}, Open  ]],

Cell[TextData[{
 "Now using ",
 Cell[BoxData[
  ButtonBox["PartsIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/PartsIntegrate"]], 
  "InlineFormula"],
 " gets us to an integral we recognize."
}], "MathCaption",
 CellID->405308593],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartsIntegrate", "[", 
  RowBox[{
   RowBox[{"Int", "[", 
    RowBox[{
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"Sin", "[", "r", "]"}]}], ",", "r"}], "]"}], ",", "r", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "r"}], ",", 
     RowBox[{"Sin", "[", "r", "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[32]:=",
 CellID->203394267],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "r", " ", 
   RowBox[{"Cos", "[", "r", "]"}]}], "-", 
  RowBox[{"Int", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"Cos", "[", "r", "]"}]}], ",", "r"}], "]"}]}]], "Output",
 ImageSize->{203, 12},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]=",
 CellID->1800963092]
}, Open  ]],

Cell[TextData[{
 "The final result is obtained from ",
 Cell[BoxData[
  ButtonBox["RemoveInt",
   BaseStyle->"Link",
   ButtonData->"paclet:IntegrationTechniques/ref/RemoveInt"]], "InlineFormula"]
}], "MathCaption",
 CellID->4682779],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RemoveInt", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "r", " ", 
     RowBox[{"Cos", "[", "r", "]"}]}], "-", 
    RowBox[{"Int", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"Cos", "[", "r", "]"}]}], ",", "r"}], "]"}]}], "]"}], "/.", 
  RowBox[{"r", "\[Rule]", 
   SqrtBox[
    RowBox[{" ", "x"}]]}]}]], "Input",
 CellLabel->"In[36]:=",
 CellID->1394055361],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SqrtBox["x"], " ", 
   RowBox[{"Cos", "[", 
    SqrtBox["x"], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    SqrtBox["x"], "]"}]}]}]], "Output",
 ImageSize->{186, 20},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[36]=",
 CellID->1161514323]
}, Open  ]],

Cell[TextData[{
 "Checking the result using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 Cell[BoxData[
  ButtonBox["Integrate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Integrate"]], "InlineFormula"],
 " function."
}], "MathCaption",
 CellID->1578536063],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Integral]", 
  RowBox[{
   RowBox[{"Sin", "[", 
    SqrtBox["x"], "]"}], 
   RowBox[{"\[DifferentialD]", "x"}]}]}]], "Input",
 CellLabel->"In[34]:=",
 CellID->442635803],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SqrtBox["x"], " ", 
   RowBox[{"Cos", "[", 
    SqrtBox["x"], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    SqrtBox["x"], "]"}]}]}]], "Output",
 ImageSize->{186, 20},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->496587813]
}, Open  ]],

Cell[TextData[{
 "The purpose of the functions in this package is to encourage students to \
recognize the steps involved in obtaining a solution to an integral and not \
just rely on the magic box of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s Integrate function returning an answer with little or no understanding \
of how the solution was found."
}], "Text",
 CellID->2027282899]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Using Integration Techniques Functions - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 10, 15, 7, 6, 44.954072}", "context" -> 
    "IntegrationTechniques`", "keywords" -> {}, "index" -> True, "label" -> 
    "Integration Techniques Tutorial", "language" -> "en", "paclet" -> 
    "IntegrationTechniques", "status" -> "", "summary" -> 
    "The functions defined in IntegrationTechniques` provide tools for having \
students become familiar with the concepts of modifying an integrand to \
produce an equivalent but recognizable integrand. Functions for simplifying \
integrals. This loads the package:", "synonyms" -> {}, "title" -> 
    "Using Integration Techniques Functions", "type" -> "Tutorial", "uri" -> 
    "IntegrationTechniques/tutorial/UsingIntegrationTechniquesFunctions"}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Mac OS X x86 (32-bit) (February 18, 2009)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[619, 21, 78, 1, 2, "TutorialColorBar"],
Cell[700, 24, 218, 5, 19, "LinkTrail"],
Cell[921, 31, 2778, 65, 46, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3724, 100, 75, 1, 50, "Title",
 CellID->509267359],
Cell[3802, 103, 404, 10, 73, "Text",
 CellID->1534169418],
Cell[4209, 115, 1492, 44, 107, "DefinitionBox",
 CellID->2096742444],
Cell[5704, 161, 76, 1, 30, "Caption",
 CellID->1891092685],
Cell[5783, 164, 66, 1, 30, "MathCaption",
 CellID->836781195],
Cell[5852, 167, 110, 3, 24, "Input",
 CellID->2058623809],
Cell[CellGroupData[{
Cell[5987, 174, 69, 1, 52, "Section",
 CellID->501870413],
Cell[6059, 177, 864, 20, 136, "Text",
 CellID->1767749522],
Cell[6926, 199, 269, 12, 49, "Text",
 CellID->129960009],
Cell[7198, 213, 85, 1, 30, "MathCaption",
 CellID->281161397],
Cell[CellGroupData[{
Cell[7308, 218, 487, 17, 58, "Input",
 CellID->1015575979],
Cell[7798, 237, 268, 9, 33, "Output",
 CellID->585452697]
}, Open  ]],
Cell[8081, 249, 114, 3, 31, "Text",
 CellID->2080891572],
Cell[8198, 254, 80, 1, 30, "MathCaption",
 CellID->1773459209],
Cell[CellGroupData[{
Cell[8303, 259, 219, 7, 24, "Input",
 CellID->1603388950],
Cell[8525, 268, 212, 7, 33, "Output",
 CellID->1533280094]
}, Open  ]],
Cell[8752, 278, 134, 4, 30, "MathCaption",
 CellID->34775858],
Cell[CellGroupData[{
Cell[8911, 286, 221, 8, 35, "Input",
 CellID->1845657267],
Cell[9135, 296, 225, 8, 41, "Output",
 CellID->1707889201]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9409, 310, 73, 1, 52, "Section",
 CellID->1227375405],
Cell[9485, 313, 646, 17, 94, "Text",
 CellID->1918002400],
Cell[10134, 332, 225, 9, 35, "Text",
 CellID->2136795330],
Cell[10362, 343, 264, 9, 30, "MathCaption",
 CellID->750082529],
Cell[CellGroupData[{
Cell[10651, 356, 282, 9, 24, "Input",
 CellID->908057013],
Cell[10936, 367, 363, 13, 33, "Output",
 CellID->1695421909]
}, Open  ]],
Cell[11314, 383, 245, 9, 30, "MathCaption",
 CellID->2142996167],
Cell[CellGroupData[{
Cell[11584, 396, 317, 11, 24, "Input",
 CellID->1888334932],
Cell[11904, 409, 286, 10, 33, "Output",
 CellID->1731866758]
}, Open  ]],
Cell[12205, 422, 186, 4, 52, "Text",
 CellID->491250268],
Cell[12394, 428, 335, 13, 33, "MathCaption",
 CellID->1516115208],
Cell[CellGroupData[{
Cell[12754, 445, 312, 10, 30, "Input",
 CellID->1454829201],
Cell[13069, 457, 399, 14, 36, "Output",
 CellID->65576465]
}, Open  ]],
Cell[13483, 474, 420, 11, 30, "MathCaption",
 CellID->484536344],
Cell[CellGroupData[{
Cell[13928, 489, 502, 17, 27, "Input",
 CellID->344344184],
Cell[14433, 508, 465, 16, 36, "Output",
 CellID->2071755470]
}, Open  ]],
Cell[14913, 527, 226, 9, 30, "MathCaption",
 CellID->694331832],
Cell[CellGroupData[{
Cell[15164, 540, 422, 14, 30, "Input",
 CellID->208962626],
Cell[15589, 556, 365, 12, 36, "Output",
 CellID->899092337]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16003, 574, 85, 1, 52, "Section",
 CellID->1349967667],
Cell[16091, 577, 512, 16, 52, "Text",
 CellID->741848714],
Cell[16606, 595, 230, 10, 36, "Text",
 CellID->2108765363],
Cell[16839, 607, 72, 1, 30, "MathCaption",
 CellID->2096829500],
Cell[CellGroupData[{
Cell[16936, 612, 449, 14, 35, "Input",
 CellID->1206759230],
Cell[17388, 628, 322, 11, 49, "Output",
 CellID->1166816342]
}, Open  ]],
Cell[17725, 642, 74, 1, 30, "MathCaption",
 CellID->2009079237],
Cell[CellGroupData[{
Cell[17824, 647, 326, 11, 40, "Input",
 CellID->1709354478],
Cell[18153, 660, 277, 9, 33, "Output",
 CellID->84482180]
}, Open  ]],
Cell[18445, 672, 266, 9, 30, "MathCaption",
 CellID->405308593],
Cell[CellGroupData[{
Cell[18736, 685, 378, 12, 24, "Input",
 CellID->203394267],
Cell[19117, 699, 399, 14, 33, "Output",
 CellID->1800963092]
}, Open  ]],
Cell[19531, 716, 233, 7, 30, "MathCaption",
 CellID->4682779],
Cell[CellGroupData[{
Cell[19789, 727, 449, 16, 30, "Input",
 CellID->1394055361],
Cell[20241, 745, 361, 14, 41, "Output",
 CellID->1161514323]
}, Open  ]],
Cell[20617, 762, 278, 11, 30, "MathCaption",
 CellID->1578536063],
Cell[CellGroupData[{
Cell[20920, 777, 195, 7, 41, "Input",
 CellID->442635803],
Cell[21118, 786, 360, 14, 41, "Output",
 CellID->496587813]
}, Open  ]],
Cell[21493, 803, 395, 9, 94, "Text",
 CellID->2027282899]
}, Open  ]]
}, Open  ]],
Cell[21915, 816, 23, 0, 40, "FooterCell"]
}
]
*)

(* End of internal cache information *)

